#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
    python_fu_plaid.py

    v 1.1 Changed default colors in dialog from white to colors
    in sample image per a suggestion from Steve 6/20/17

    v 1.0 initial release 6/6/17
    Create a plaid RGB image from user input

    <Image>/File/Create/Render/Plaid...
    PEP8 OK 6/20/17

    Tested working: Not yet on Ubuntu 16.04 Xenial Gimp 2.8.16
                    Not yet on Windows 10 Gimp 2.8.22



    License:

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    The GNU Public License is available at
    http://www.gnu.org/copyleft/gpl.html
'''


from gimpfu import *


def python_plaidmaker(width, height, resol, color0, color1,
                      color2, color3, color4, color5, color6, color7):
    pdb.gimp_context_push()
    side = int(max(width, height))
    image = pdb.gimp_image_new(side, side, RGB)
    pdb.gimp_image_set_resolution(image, resol, resol)
    tlayer0 = pdb.gimp_layer_new(image, side, side, RGB, "layer one", 100, 0)
    pdb.gimp_image_insert_layer(image, tlayer0, None, 0)
    pdb.gimp_item_set_visible(image.layers[0], TRUE)
    pdb.gimp_image_set_active_layer(image, image.layers[0])
    pdb.gimp_drawable_fill(image.layers[0], 3)
    colors = [color0, color1, color2, color3, color4, color5, color6, color7]
    corner_list = list()
    for x in range(image.width):
        if x % 4 == 0:
            corner_list.append(x)
    num_stripes = (image.width/4)
    color_counter = 0
    pdb.gimp_item_set_visible(image.layers[0], TRUE)
    pdb.gimp_image_set_active_layer(image, image.layers[0])
    pdb.gimp_image_select_item(image, 0, image.layers[0])
    for x in corner_list:
        pdb.gimp_image_select_rectangle(image,
                                        2,
                                        float(x),
                                        0,
                                        float(num_stripes),
                                        float(image.width))
        if color_counter >= len(colors):
            color_counter = 0
        pdb.gimp_context_set_foreground(colors[color_counter])
        pdb.gimp_edit_fill(image.layers[0], 0)
        color_counter += 1
    pdb.gimp_selection_none(image)
    pdb.gimp_image_select_item(image, 0, image.layers[0])
    tlayer1 = pdb.gimp_layer_copy(image.layers[0], TRUE)
    pdb.gimp_item_set_name(tlayer1, "layer two")
    pdb.gimp_image_insert_layer(image, tlayer1, None, -1)
    tlayer1 = pdb.gimp_item_transform_rotate_simple(tlayer1, 0, TRUE, 0, 0)
    pdb.gimp_layer_set_opacity(image.layers[0], 50)
    pdb.gimp_layer_set_opacity(image.layers[1], 50)
    pdb.gimp_item_set_visible(image.layers[1], TRUE)
    pdb.gimp_image_set_active_layer(image, tlayer1)
    my_selection = pdb.gimp_image_get_floating_sel(image)
    pdb.gimp_floating_sel_anchor(my_selection)
    tlayer2 = pdb.gimp_image_merge_visible_layers(image, CLIP_TO_IMAGE)
    pdb.gimp_item_set_name(tlayer2, "plaid")
    pdb.gimp_item_set_visible(image.layers[0], TRUE)
    if(side != width or side != height):
        pdb.gimp_image_crop(image, width, height, 0, 0)
    pdb.gimp_context_pop()
    gimp.Display(image)
    gimp.displays_flush
    return image

register(
        "python_fu_plaid",
        "Create a new plaid image",
        "Create a new plaid image",
        "hnd", "hnd", "2017",
        "Create plaid image",
        "",
        [
            (PF_SPINNER, "width", "Width (px)", 1024, (16, 4096, 16)),
            (PF_SPINNER, "height", "Height (px)", 1024, (16, 4096, 16)),
            (PF_SPINNER, "resol", "Resolution (px)", 72, (1, 1000, 1)),
            (PF_COLOR, "color0", "Color", (0.804, 0.753, 0.753)),
            (PF_COLOR, "color1", "Color", (0.694, 0.667, 0.369)),
            (PF_COLOR, "color2", "Color", (0.698, 0.675, 0.333)),
            (PF_COLOR, "color3", "Color", (0.8, 0.498, 0.765)),
            (PF_COLOR, "color4", "Color", (0.804, 0.761, 0.714)),
            (PF_COLOR, "color5", "Color", (0.78, 0.518, 0.792)),
            (PF_COLOR, "color6", "Color", (0.616, 0.863, 0.749)),
            (PF_COLOR, "color7", "Color", (0.722, 0.769, 0.51))
        ],
        [
        ],
        python_plaidmaker,
        menu="<Image>/File/Create/Render"
        )

main()
#
